@@ -9,7 +9,7 @@ use App::cpm::Logger;
 use Module::Metadata;
 use IO::Handle;
 use version;
-our $VERSION = '0.910';
+our $VERSION = '0.911';
 
 sub new {
     my ($class, %option) = @_;
@@ -316,14 +316,15 @@ sub is_satisfied {
             next;
         }
         next if $self->{target_perl} and $self->is_core($package, $version_range);
-        next if $self->is_installed($package, $version_range);
-        my ($resolved) = grep { $_->providing($package, $version_range) } @distributions;
-        next if $resolved && $resolved->installed;
 
-        $is_satisfied = 0 if defined $is_satisfied;
-        if (!$resolved) {
+        my ($resolved) = grep { $_->providing($package, $version_range) } @distributions;
+        if ($resolved) {
+            next if $resolved->installed;
+        } else {
+            next if $self->is_installed($package, $version_range);
             push @need_resolve, $req;
         }
+        $is_satisfied = 0 if defined $is_satisfied;
     }
     return ($is_satisfied, @need_resolve);
 }
